@@ -43,12 +43,12 @@ class SlideShow(QWidget):
         lay.addWidget(self.__prevBtn, alignment=Qt.AlignLeft)
         lay.addWidget(self.__nextBtn, alignment=Qt.AlignRight)
 
-        navWidget = QWidget()
-        navWidget.setLayout(lay)
+        self.__navWidget = QWidget()
+        self.__navWidget.setLayout(lay)
 
         lay = QGridLayout()
         lay.addWidget(self.__view, 0, 0, 3, 1)
-        lay.addWidget(navWidget, 0, 0, 3, 1)
+        lay.addWidget(self.__navWidget, 0, 0, 3, 1)
         lay.addWidget(self.__btnWidget, 2, 0, 1, 1, Qt.AlignCenter)
         self.setLayout(lay)
 
@@ -103,8 +103,14 @@ class SlideShow(QWidget):
         self.__view.setFilename(self.__filenames[0])
         self.__btnWidget.setLayout(lay)
 
-    def setNavigationButtonVisible(self, f):
+    def setNavigationButtonVisible(self, f: bool):
         self.__navWidget.setVisible(f)
 
-    def setBottomButtonVisible(self, f):
-        self.__btnWidget.setVisible(f)
\ No newline at end of file
+    def setBottomButtonVisible(self, f: bool):
+        self.__btnWidget.setVisible(f)
+
+    def setTimerEnabled(self, f: bool):
+        if f:
+            self.__timer.start()
+        else:
+            self.__timer.stop()
\ No newline at end of file
